@@ -10,6 +10,7 @@
 /*                                                                      */
 /* Created April 13 1992 by CJL                                         */
 /* new code to search for maximum over ionospheric values 2012.1.27 rjc */
+/* changed ionosphere search to be 3 level                2016.3.9  rjc */
 /************************************************************************/
 #include <stdio.h>
 #include <stdlib.h>
@@ -17,8 +18,9 @@
 #include "vex.h"
 #include "pass_struct.h"
 #include "param_struct.h"
-
-#define MAX_ION_PTS 100
+                                    // number of points in fine search
+#define N_FINE_PTS 11
+#define N_MED_PTS 11                // number of points in medium search
 
 int
 fringe_search (root, param, pass)
@@ -32,11 +34,11 @@ struct type_pass *pass;
         ilmax,
         level,
         ionloop,
-        fine_pts,
         rc,
         koff,
         nip;
     double coarse_spacing,
+           medium_spacing,
            fine_spacing,
            step,
            bottom,
@@ -102,9 +104,10 @@ struct type_pass *pass;
             }
                                         // prepare for ionospheric search
     center = (param->win_ion[0] + param->win_ion[1]) / 2.0;
-    if (param->ion_pts > MAX_ION_PTS)   // condition total # of points
+                                        // condition total # of points
+    if (param->ion_pts > MAX_ION_PTS - N_FINE_PTS - 1)   
         {
-        param->ion_pts = MAX_ION_PTS;
+        param->ion_pts = MAX_ION_PTS - N_MED_PTS - N_FINE_PTS - 1;   
         msg ("limited ion search to %d points", 2, param->ion_pts);
         }
     coarse_spacing = param->win_ion[1] - param->win_ion[0];
@@ -114,11 +117,11 @@ struct type_pass *pass;
         nip = 0;
         }
 
-    fine_spacing = 0.2 * coarse_spacing;
-    fine_pts = 7;
+    medium_spacing = 2.0;
+    fine_spacing = 0.4;
                                         // do search over ionosphere differential
                                         // TEC (if desired)
-    for (level=0; level<3; level++)     // search level (coarse, fine, final)
+    for (level=0; level<4; level++)     // search level (coarse, medium, fine, final)
         {
         switch (level)
             {
@@ -127,9 +130,9 @@ struct type_pass *pass;
                 step = coarse_spacing;
                 bottom = center - (ilmax - 1) / 2.0 * step;
                 if (param->ion_pts == 1)// if no ionospheric search, proceed
-                    level = 2;          // immediately to final delay & rate search
+                    level = 3;          // immediately to final delay & rate search
                 break;
-            case 1:                     // set up for fine ion search 
+            case 1:                     // set up for medium ion search 
                                         // find maximum from coarse search
                                         // should do parabolic interpolation here
                 valmax = -1.0;
@@ -145,19 +148,47 @@ struct type_pass *pass;
                     status.dtec[nip++][1] = values[k];
                     }
                 if (kmax == 0)          // coarse maximum up against lower edge?
-                    center = bottom + (fine_pts - 1) / 2.0 * fine_spacing;
+                    center = bottom + (N_MED_PTS - 1) / 2.0 * medium_spacing;
                 else if (kmax == param->ion_pts) // upper edge?
                     center = bottom + (kmax - 1) * step 
-                                    - (fine_pts - 1) / 2.0 * fine_spacing;
+                                    - (N_MED_PTS - 1) / 2.0 * medium_spacing;
                 else                    // max was one of the interior points
                     center = bottom + kmax * step;
 
-                ilmax = fine_pts;
+                ilmax = N_MED_PTS;
+                step = medium_spacing;
+                                        // make medium search symmetric about level 0 max
+                bottom = center - (ilmax - 1) / 2.0 * step;
+                break;
+            case 2:                     // set up for fine ion search 
+                                        // find maximum from medium search
+                                        // should do parabolic interpolation here
+                valmax = -1.0;
+                for (k=0; k<ilmax; k++)
+                    {
+                    if (values[k] > valmax)
+                        {
+                        valmax = values[k];
+                        kmax = k;
+                        }
+                                        // store this medium ionosphere point
+                    status.dtec[nip][0] = bottom + k * step;
+                    status.dtec[nip++][1] = values[k];
+                    }
+                if (kmax == 0)          // medium maximum up against lower edge?
+                    center = bottom + (N_FINE_PTS - 1) / 2.0 * fine_spacing;
+                else if (kmax == param->ion_pts) // upper edge?
+                    center = bottom + (kmax - 1) * step 
+                                    - (N_FINE_PTS - 1) / 2.0 * fine_spacing;
+                else                    // max was one of the interior points
+                    center = bottom + kmax * step;
+
+                ilmax = N_FINE_PTS;
                 step = fine_spacing;
                                         // make fine search symmetric about level 0 max
                 bottom = center - (ilmax - 1) / 2.0 * step;
                 break;
-            case 2:                     // final evaluation
+            case 3:                     // final evaluation
                                         // find maximum from fine search
                 valmax = -1.0;
                 for (k=0; k<ilmax; k++)
