@@ -37,12 +37,12 @@ struct station_struct *stn2,
 struct freqlist *fl)
     {
     int i, j, nf, ch1, ch2, ch, minindex, index, mismatch, lsb, usb;
-    double freqs[MAX_CHAN_PP], minfreq, freq, bw, fdiff;
+    double freqs[MAXFREQ], minfreq, freq, bw, fdiff;
     struct chan_struct *chnl, *st1ch, *st2ch;
     extern struct type_param param;
 
                                         /* Initialize fl array */
-    for (i=0; i<MAX_CHAN_PP; i++)
+    for (i=0; i<MAXFREQ; i++)
         {
         fl[i].sky_frequency = -1.0;
         for (j=0; j<4; j++)
@@ -52,7 +52,7 @@ struct freqlist *fl)
                                         /* which are distinct, and */
                                         /* present at both stations */
     nf = 0;
-    for (ch1=0; ch1<MAX_CHAN_PP; ch1++)
+    for (ch1=0; ch1<MAXFREQ; ch1++)
         {
         st1ch = stn1->channels + ch1;
         freq = st1ch->sky_frequency;
@@ -63,7 +63,7 @@ struct freqlist *fl)
                 break;
         if (i == nf)
             {
-            for (ch2=0; ch2<MAX_CHAN_PP; ch2++)
+            for (ch2=0; ch2<MAXFREQ; ch2++)
                 {
                 st2ch = stn2->channels + ch2;
                                         /* Criterion is freq diff as fraction of bandwidth */
@@ -71,7 +71,7 @@ struct freqlist *fl)
                 if (fdiff/bw < param.fmatch_bw_pct/100.0)
                     break;
                 }
-            if (ch2 < MAX_CHAN_PP)
+            if (ch2 < MAXFREQ)
                 {
                 freqs[nf] = freq;
                 nf++;
@@ -103,7 +103,7 @@ struct freqlist *fl)
                                         /* There should be 0 or 1 of each */
     for (i=0; i<nf; i++)
         {
-        for (ch=0; ch<MAX_CHAN_PP; ch++)
+        for (ch=0; ch<MAXFREQ; ch++)
             {
                                         /* Locate frequency entry */
             chnl = stn1->channels + ch;
@@ -114,8 +114,10 @@ struct freqlist *fl)
                                         /* Which combo is it? */
                                         /* UL=0,LL=1,UR=2,LR=3 */
             index = 0;
-            if (chnl->net_sideband == 'L') index += 1;
-            if (chnl->polarization == 'R') index += 2;
+            if (chnl->net_sideband == 'L') 
+                index += 1;
+            if (chnl->polarization == 'R' || chnl->polarization == 'Y') 
+                index += 2;
                                         /* Should be one and only */
             if (fl[i].ref_chnos[index] >= 0)
                 {
@@ -127,7 +129,7 @@ struct freqlist *fl)
             fl[i].ref_chnos[index] = ch;
             }
                                         /* Repeat for remote station */
-        for (ch=0; ch<MAX_CHAN_PP; ch++)
+        for (ch=0; ch<MAXFREQ; ch++)
             {
             chnl = stn2->channels + ch;
             freq = chnl->sky_frequency / 1e6;
@@ -138,8 +140,10 @@ struct freqlist *fl)
                                         /* Which combo is it? */
                                         /* UL=0,LL=1,UR=2,LR=3 */
             index = 0;
-            if (chnl->net_sideband == 'L') index += 1;
-            if (chnl->polarization == 'R') index += 2;
+            if (chnl->net_sideband == 'L') 
+                index += 1;
+            if (chnl->polarization == 'R' || chnl->polarization == 'Y') 
+                index += 2;
                                         /* Should be one and only */
             if (fl[i].rem_chnos[index] >= 0)
                 {
