@@ -50,8 +50,10 @@ void norm_fx (struct type_pass *pass,
         ibegin,
         sindex,
         pol,
+        pols,                       // bit-mapped pols to be processed in this pass
         usb_present, lsb_present,
-        usb_bypol[4],lsb_bypol[4];
+        usb_bypol[4],lsb_bypol[4], 
+        lastpol[2];                 // last pol index with data present, by sideband
 
     int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L/X/H, 1:R/Y/V
     static fftw_plan fftplan;
@@ -63,9 +65,13 @@ void norm_fx (struct type_pass *pass,
         {
         pol = pass->pol;            // single pol being done per pass
         ips = pol;
+        pols = 1 << pol;
         }
     else                            // linear combination of polarizations
+        {
         ips = 0;
+        pols = param.pol;
+        }
         
                                     // do fft plan only iff nlags changes
     if (param.nlags != nlags)
@@ -92,11 +98,21 @@ void norm_fx (struct type_pass *pass,
 
     usb_present = FALSE;
     lsb_present = FALSE;
+    lastpol[0] = ips;
+    lastpol[1] = ips;
                                     // check sidebands for each pol. for data
     for (ip=ips; ip<pass->pol+1; ip++)
         {
-        usb_bypol[ip] = ((datum->flag & (USB_FLAG << 2*ip)) != 0);
-        lsb_bypol[ip] = ((datum->flag & (LSB_FLAG << 2*ip)) != 0);
+        usb_bypol[ip] = ((datum->flag & (USB_FLAG << 2*ip)) != 0)
+                     && ((pols & (1 << ip)) != 0);
+        lsb_bypol[ip] = ((datum->flag & (LSB_FLAG << 2*ip)) != 0)
+                     && ((pols & (1 << ip)) != 0);
+        pass->pprods_present[ip] |= usb_bypol[ip] || lsb_bypol[ip];
+
+        if (usb_bypol[ip])
+            lastpol[0] = ip;
+        if (lsb_bypol[ip])
+            lastpol[1] = ip;
 
         usb_present |= usb_bypol[ip];
         lsb_present |= lsb_bypol[ip];
@@ -123,27 +139,27 @@ void norm_fx (struct type_pass *pass,
         switch (pol)
             {
             case POL_LL: t120 = datum->apdata_ll[sb];
-                         polcof = (param.pol == POL_IXY) ?
+                         polcof = (pass->npols > 1) ?
                              cos (param.par_angle[1] - param.par_angle[0]) :
                              1.0;
                          break;
             case POL_RR: t120 = datum->apdata_rr[sb];
-                         polcof = (param.pol == POL_IXY) ?
+                         polcof = (pass->npols > 1) ?
                              cos (param.par_angle[1] - param.par_angle[0]) :
                              1.0;
                          break;
             case POL_LR: t120 = datum->apdata_lr[sb];
-                         polcof = (param.pol == POL_IXY) ?
+                         polcof = (pass->npols > 1) ?
                              sin (param.par_angle[1] - param.par_angle[0]) :
                              1.0;
                          break;
             case POL_RL: t120 = datum->apdata_rl[sb];
-                         polcof = (param.pol == POL_IXY) ?
+                         polcof = (pass->npols > 1) ?
                             -sin (param.par_angle[1] - param.par_angle[0]) :
                              1.0;
                          break;
             }
-        polcof_sum += polcof;
+        polcof_sum += fabs (polcof);
                                     // sanity test
         if (t120 -> type != SPECTRAL)
             {
@@ -152,7 +168,7 @@ void norm_fx (struct type_pass *pass,
             }
         
                                     // determine data weights by sideband
-        if (ip == pass->pol)
+        if (ip == lastpol[sb])
             {                       // last included polarization, do totals
             status.ap_num[sb][fr]++;
             status.total_ap++;
@@ -228,8 +244,8 @@ void norm_fx (struct type_pass *pass,
         }                           // bottom of polarization loop
 
                                     // also skip over this next section, if no data
-      if (sb == 0 & usb_present == 0
-       || sb == 1 & lsb_present == 0)
+      if (sb == 0 && usb_present == 0
+       || sb == 1 && lsb_present == 0)
           continue;
 
                                     /* apply spectral filter as needed */
