@@ -555,6 +555,56 @@ int parser ()
                            cb_ptr -> delay_offs[i].rem = fval;
                            }
                        }
+
+                   else if (toknum == SAMPLER_DELAY_L_ || toknum == SAMPLER_DELAY_X_)
+                       {
+                       if (nv >= MAX_SAMP)
+                           {
+                           msg ("Too many (%d) sampler delays specified", 2, nv+1);
+                           return (-1);
+                           }
+                                   /* get coefficients from appropriate place */
+                       if (tokens[ntok].category == INTEGER)
+                           fval = tval;
+                       else
+                           fval = float_values[tval];
+                       fval *= 1e-9;      // convert ns -> sec
+                                          // insert to station, or rem if no wildcard
+                       if (cb_ptr -> baseline[1] == WILDCARD)
+                           cb_ptr -> sampler_delay[nv][LXH].ref = fval;
+                       else if (cb_ptr -> baseline[0] == WILDCARD)
+                           cb_ptr -> sampler_delay[nv][LXH].rem = fval;
+                       else 
+                           {
+                           cb_ptr -> sampler_delay[nv][LXH].ref = 0.0;
+                           cb_ptr -> sampler_delay[nv][LXH].rem = fval;
+                           }
+                       }
+
+                   else if (toknum == SAMPLER_DELAY_R_ || toknum == SAMPLER_DELAY_Y_)
+                       {
+                       if (nv >= MAX_SAMP)
+                           {
+                           msg ("Too many (%d) sampler delays specified", 2, nv+1);
+                           return (-1);
+                           }
+                                   /* get coefficients from appropriate place */
+                       if (tokens[ntok].category == INTEGER)
+                           fval = tval;
+                       else
+                           fval = float_values[tval];
+                       fval *= 1e-9;      // convert ns -> sec
+                                          // insert to station, or rem if no wildcard
+                       if (cb_ptr -> baseline[1] == WILDCARD)
+                           cb_ptr -> sampler_delay[nv][RYV].ref = fval;
+                       else if (cb_ptr -> baseline[0] == WILDCARD)
+                           cb_ptr -> sampler_delay[nv][RYV].rem = fval;
+                       else 
+                           {
+                           cb_ptr -> sampler_delay[nv][RYV].ref = 0.0;
+                           cb_ptr -> sampler_delay[nv][RYV].rem = fval;
+                           }
+                       }
                nv++;                       /* bump index for next vector parm */
                break;
 
