@@ -26,7 +26,7 @@ struct scan_struct *ovex;
 struct type_param *param;
 struct type_pass *pass;
     {
-    int i, j, k, stn, n, fr, ntones, nin, mask;
+    int i, j, k, stn, n, fr, ntones, nin, mask, chind;
     double delay_offset, rate_offset, pcfreq_hz,
            pcphas[2][2],            // indexed by [stn][pol]
            pcfreq[2];
@@ -94,6 +94,7 @@ struct type_pass *pass;
         for (fr = 0; fr < pass->nfreq; fr++)  
             {
             j = fcode(pass->pass_data[fr].freq_code);
+            chind = pass->pass_data[fr].ch_idx;
 
                                     // copy delay calib. values into status array
             status.delay_offs[fr][stn] = (stn) ? pass->control.delay_offs[j].rem 
@@ -127,25 +128,25 @@ struct type_pass *pass;
                     {               // must compute frequency for this tone
                                     // assume for now that all ovex channels the same spacing
                     pcfreq_hz = fmod (pass->pass_data[fr].frequency * 1e6
-                                    - ovex->st[n].channels[0].pcal_base_freq,
-                                      ovex->st[n].channels[0].pcal_spacing);
+                                    - ovex->st[n].channels[chind].pcal_base_freq,
+                                      ovex->st[n].channels[chind].pcal_spacing);
 
                                     // pcfreq_hz is positive distance from next lower line
                     if (pcfreq_hz < 0.0)
-                        pcfreq_hz += ovex->st[n].channels[0].pcal_spacing;
+                        pcfreq_hz += ovex->st[n].channels[chind].pcal_spacing;
 
                                     // nearest freq rail depends on sideband
-                    if (ovex->st[n].channels[fr].net_sideband == 'U')
+                    if (ovex->st[n].channels[chind].net_sideband == 'U')
                         {               // distance to next line is complement
-                        pcfreq_hz = ovex->st[n].channels[0].pcal_spacing - pcfreq_hz;
+                        pcfreq_hz = ovex->st[n].channels[chind].pcal_spacing - pcfreq_hz;
                                     // now set freq to tone # within band (1 relative)
-                        pcfreq_hz += (pcfreq[stn] - 1) * ovex->st[n].channels[0].pcal_spacing;
+                        pcfreq_hz += (pcfreq[stn] - 1) * ovex->st[n].channels[chind].pcal_spacing;
                         }
                     else            // set up tone frequency for net LSB
                         {           // lsb implemented using negative frequencies
                                     // now set freq to tone # within band (1 relative)
                         pcfreq_hz = - pcfreq_hz 
-                                    + (pcfreq[stn] + 1) * ovex->st[n].channels[0].pcal_spacing;
+                                    + (pcfreq[stn] + 1) * ovex->st[n].channels[chind].pcal_spacing;
                         }
                     msg ("fcode %c freq %lf tone request %lf pc_freqhz %lf", 0,
                           pass->pass_data[fr].freq_code, pass->pass_data[fr].frequency, 
@@ -188,22 +189,22 @@ struct type_pass *pass;
 
                                     // assume for now that all ovex channels the same spacing
                 pcfreq_hz = fmod (pass->pass_data[fr].frequency * 1e6
-                                - ovex->st[n].channels[0].pcal_base_freq,
-                                  ovex->st[n].channels[0].pcal_spacing);
+                                - ovex->st[n].channels[chind].pcal_base_freq,
+                                  ovex->st[n].channels[chind].pcal_spacing);
 
                                     // pcfreq_hz is positive distance from next lower line
                 if (pcfreq_hz <= 0.0)
-                    pcfreq_hz += ovex->st[n].channels[0].pcal_spacing;
+                    pcfreq_hz += ovex->st[n].channels[chind].pcal_spacing;
                                     // nearest freq rail depends on sideband
-                if (ovex->st[n].channels[0].net_sideband == 'U')
+                if (ovex->st[n].channels[chind].net_sideband == 'U')
                                     // for USB, distance to next line is complement
-                    pcfreq_hz = ovex->st[n].channels[0].pcal_spacing - pcfreq_hz;
+                    pcfreq_hz = ovex->st[n].channels[chind].pcal_spacing - pcfreq_hz;
                                     // set up tone frequency for net LSB
                 else                // lsb implemented using negative frequencies
                     pcfreq_hz = - pcfreq_hz;
                                     // calculate the number of tones in the band
-                ntones = ((ovex->st[n].channels[0].bandwidth - fabs (pcfreq_hz))
-                        / (ovex->st[n].channels[0].pcal_spacing)) + 1;
+                ntones = ((ovex->st[n].channels[chind].bandwidth - fabs (pcfreq_hz))
+                        / (ovex->st[n].channels[chind].pcal_spacing)) + 1;
                                     // condition result
                 ntones = (ntones > MAX_PCF) ? MAX_PCF : ntones;
                                     // go through list of all tones that are inband,
@@ -223,14 +224,14 @@ struct type_pass *pass;
                         pass->pcinband[stn][fr][nin] = k;
                         msg ("adding pcinband[%d][%d][%d] %d pcfreq_hz %lf sb %c", 
                               0,stn, fr, nin, pass->pcinband[stn][fr][nin], 
-                              pcfreq_hz, ovex->st[n].channels[0].net_sideband);
+                              pcfreq_hz, ovex->st[n].channels[chind].net_sideband);
                         nin++;
                         }
                                     // move on to next tone in the band
-                    if (ovex->st[n].channels[0].net_sideband == 'U')
-                        pcfreq_hz += ovex->st[n].channels[0].pcal_spacing;
+                    if (ovex->st[n].channels[chind].net_sideband == 'U')
+                        pcfreq_hz += ovex->st[n].channels[chind].pcal_spacing;
                     else
-                        pcfreq_hz -= ovex->st[n].channels[0].pcal_spacing;
+                        pcfreq_hz -= ovex->st[n].channels[chind].pcal_spacing;
                     mask >>= 1;     // access next bit (i.e. tone) in mask
                     }
                                     // set rest of indices to -1 (unused)
