@@ -19,15 +19,17 @@ int search (struct type_pass *pass)
     {
     fftw_complex *data; 
     double mb_delay[MBD_GRID_MAX]; 
-    complex rate_spectrum[MAXFREQ][MAXAP];
+    static complex rate_spectrum[MAXFREQ][MAXAP];
     static double amps[MBD_GRID_MAX][MAXAP], drtemp[MAXAP];
-    int cnt, fr, i, j, station, lag, dr_index, mbd_index, mbdmax[2*MAXLAG], ap, newmax;
-    int drmax[2*MAXLAG], max_mbd_cell, max_dr_cell, max_lag, drlag;
+    int cnt, fr, i, j, station, lag, dr_index, mbd_index, ap, newmax;
+    int max_mbd_cell, max_dr_cell, max_lag, drlag;
     int n, jlo, jhi;
+    static int mbdmax[2*MAXLAG], drmax[2*MAXLAG];
     extern struct type_param param;
     extern struct type_status status;
     extern struct type_plot plot;
-    double max_amp[2*MAXLAG], global_max, amp, c_phase(), c_mag();
+    double global_max, amp, c_phase(), c_mag();
+    static double max_amp[2*MAXLAG];
     extern int do_accounting;
 
     fftw_plan fftplan;
